@@ -5,6 +5,6 @@ kivy.require("1.11.1")
 
 import kivy_matplotlib_widget.factory_registers  # NOQA
 
-__version__ = "0.1.0"
-__description__ = "A Matplotlib interactive idget for kivy"
+__version__ = "0.2.0"
+__description__ = "A Matplotlib interactive widget for kivy"
 __author__ = "mp-007"
\ No newline at end of file
